get_ftp_data: Download FTP Data

Description Usage Arguments Value Examples

View source: R/download_tools.R

Description

Download data from an FTP server.

Usage

1
get_ftp_data(ftp_address, dir_path, fnames, parse_fun, ..., verbose = TRUE)

Arguments

ftp_address

The FTP server address.

dir_path

FTP directory to search.

fnames

A vector of file names in the package to download. Supports regex.

parse_fun

A function to parse datasets. Default assumes that all files in fnames can be parsed using readr::read_csv().

...

Additional arguments to pass to parse_fun.

verbose

If TRUE, display descriptive messages.

Value

a named list of dataframes.

Examples

1
2
3
4
5
6
## Not run: 
get_ftp_data("ftp://ftp.dfg.ca.gov", "IEP_Zooplankton", "MysidMatrix",
  parse_remote_excel, sheet = "Mysid CPUE Matrix 1972-2018 ",
  guess_max = 100000L)

## End(Not run)

InteragencyEcologicalProgram/smonitr documentation built on Nov. 9, 2020, 7:01 a.m.