Description Usage Arguments Value Examples
View source: R/download_tools.R
Download files from an Open Data Portal, assuming it uses the CKAN API.
1 2 3 4 5 6 7 8 | get_odp_data(
portal_url = "https://data.cnra.ca.gov",
pkg_id,
fnames,
parse_fun,
...,
verbose = TRUE
)
|
portal_url |
The base URL of the portal, e.g.
|
pkg_id |
The package identifier. |
fnames |
A vector of file names in the package to download. Supports regex. |
parse_fun |
A function to parse datasets. Default assumes that
all files in fnames can be parsed using |
... |
Additional arguments to pass to |
verbose |
If |
a named list of dataframes.
1 2 3 4 | ## Not run:
get_odp_data(pkg_id = "dayflow", "Dayflow Results")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.