round_to_mult: Round an integer to the nearest multiple

Description Usage Arguments Value

View source: R/plot_utils.R

Description

Used to round a year value to the nearest multiple of a defined value. This is an internal function used to define x-axis breaks for plots.

Usage

1
round_to_mult(num, mult)

Arguments

num

Integer to round

mult

Mulitple value to round to

Value

A value rounded to the nearest multiple of the mult parameter


InteragencyEcologicalProgram/smonitr documentation built on Nov. 9, 2020, 7:01 a.m.