Description Usage Arguments Value
Standardizes the y-axis a ggplot. This is really just a wrapper
aroundggplot2::scale_y_continuous() with a default setting
for the expand argument to reduce whitespace.
1 | smr_y_axis(expand = expansion(mult = c(0, 0.05)), ...)
|
expand |
For position scales, a vector of range expansion constants used to add some
padding around the data to ensure that they are placed some distance
away from the axes. Use the convenience function |
... |
Other arguments passed on to |
A ggplot continuous x-axis scale.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.