Description Usage Arguments Value Examples
View source: R/download_tools.R
Download data from an FTP server.
1 | get_ftp_data(ftp_address, dir_path, fnames, parse_fun, ..., verbose = TRUE)
|
ftp_address |
The FTP server address. |
dir_path |
FTP directory to search. |
fnames |
A vector of file names in the package to download. Supports regex. |
parse_fun |
A function to parse datasets. Default assumes that
all files in fnames can be parsed using |
... |
Additional arguments to pass to |
verbose |
If |
a named list of dataframes.
1 2 3 4 5 6 | ## Not run:
get_ftp_data("ftp://ftp.dfg.ca.gov", "IEP_Zooplankton", "MysidMatrix",
parse_remote_excel, sheet = "Mysid CPUE Matrix 1972-2018 ",
guess_max = 100000L)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.