Description Usage Arguments Value
Used to round a year value to the nearest multiple of a defined value. This is an internal function used to define x-axis breaks for plots.
1 | round_to_mult(num, mult)
|
num |
Integer to round |
mult |
Mulitple value to round to |
A value rounded to the nearest multiple of the mult parameter
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.